You can read more about how to find older records in [Civil court cases: Chancery Division since 1875](https://www.nationalarchives.gov.uk/help-with-your-research/research-guides/civil-court-cases-chancery-division-since-1875/){target="\_blank"}
